@@ -3,7 +3,7 @@ package Games::Solitaire::Verify::App::CmdLine;
 use strict;
 use warnings;
 
-use base 'Games::Solitaire::Verify::Base';
+use parent 'Games::Solitaire::Verify::Base';
 
 use Data::Dumper qw(Dumper);
 
@@ -12,6 +12,8 @@ use Getopt::Long qw(GetOptionsFromArray);
 use Games::Solitaire::Verify::VariantsMap;
 use Games::Solitaire::Verify::Solution;
 
+our $VERSION = '0.1201';
+
 __PACKAGE__->mk_acc_ref(
     [
         qw(
