@@ -11,13 +11,13 @@ Games::Solitaire::Verify::Base - a base class.
 
 use vars qw($VERSION);
 
-$VERSION = '0.1200';
+$VERSION = '0.1201';
 
 use Class::XSAccessor;
 
 =head1 SYNOPSIS
 
-    use base 'Games::Solitaire::Verify::Base';
+    use parent 'Games::Solitaire::Verify::Base';
 
     sub _init
     {
