@@ -14,9 +14,9 @@ Version 0.03
 
 =cut
 
-our $VERSION = '0.1200';
+our $VERSION = '0.1201';
 
-use base 'Games::Solitaire::Verify::Base';
+use parent 'Games::Solitaire::Verify::Base';
 
 use Games::Solitaire::Verify::Exception;
 
